@@ -80,7 +80,7 @@ class MIData(components.ExperimentData):
         mode = mode.lower()
         if mode == 'train':
             if mi_labels is None:
-                raise ValueError('Attributes mi_labels, control_state_labels '
+                raise ValueError('Attributes mi_labels, '
                                  'should be provided in train mode')
 
         # Standard attributes
@@ -143,7 +143,7 @@ class MIDataset(components.Dataset):
             recordings (e.g., 'mi_left_right', 'rest_mi'). It is
             mandatory when a recording of the dataset contains more than 1
             experiment data
-        experiment_mode : str {'train'|'test'|None}
+        experiment_mode : str {'train'|'test'|'guided test'|None}
             Mode of the experiment. If this dataset will be used to fit a model,
             set to train to avoid errors
         track_attributes: dict of dicts or None
@@ -203,7 +203,7 @@ class MIDataset(components.Dataset):
             }
         }
 
-        if experiment_mode == 'train':
+        if experiment_mode in ['train', 'guided_test']:
             default_track_attributes_train = {
                 'mi_labels': {
                     'track_mode': 'concatenate',
@@ -291,13 +291,13 @@ class MIDataset(components.Dataset):
                          'type': MIData}
         )
         # Check mode
-        if self.experiment_mode is not None:
-            checker.add_consistency_rule(
-                rule='check-attribute-value',
-                rule_params={'attribute': 'mode',
-                             'value': self.experiment_mode},
-                parent=self.experiment_att_key
-            )
+        # if self.experiment_mode is not None:
+        #     checker.add_consistency_rule(
+        #         rule='check-attribute-value',
+        #         rule_params={'attribute': 'mode',
+        #                      'value': self.experiment_mode},
+        #         parent=self.experiment_att_key
+        #     )
 
         # Check track_attributes
         if self.track_attributes is not None:
@@ -330,7 +330,7 @@ class StandardPreprocessing(components.ProcessingMethod):
     reference (CAR) spatial filter.
     """
 
-    def __init__(self, order=4, cutoff=[0.05, 63], btype='bandpass',
+    def __init__(self, order=5, cutoff=[0.05, 63], btype='bandpass',
                  temp_filt_method='sosfiltfilt'):
         super().__init__(fit_transform_signal=['signal'],
                          fit_transform_dataset=['dataset'])
@@ -543,7 +543,7 @@ class StandardFeatureExtraction(components.ProcessingMethod):
             norm_epoch = None
 
         features = normalize_epochs(features, norm_epochs=norm_epoch,
-                                        norm=self.norm)
+                                    norm=self.norm)
         # Resample each epoch to the target frequency
         if self.target_fs is not None:
             if self.target_fs > fs:
@@ -745,9 +745,10 @@ class CSPFeatureExtraction(StandardFeatureExtraction):
                 De-mixing matrix (activation patterns are stored in columns).
         """
         super().__init__(w_epoch_t=w_epoch_t, target_fs=target_fs,
-                 baseline_mode=baseline_mode,
-                 w_baseline_t=w_baseline_t, norm=norm,
-                 concatenate_channels=concatenate_channels, safe_copy=safe_copy)
+                         baseline_mode=baseline_mode,
+                         w_baseline_t=w_baseline_t, norm=norm,
+                         concatenate_channels=concatenate_channels,
+                         safe_copy=safe_copy)
         self.CSP = CSP(n_filters=n_filters)
 
     def fit(self, X, y):
@@ -826,8 +827,8 @@ class CSPFeatureExtraction(StandardFeatureExtraction):
         return features
 
     def transform_dataset(self, dataset, show_progress_bar=True):
-        features, track_info = super().transform_dataset(dataset=dataset,
-                                  show_progress_bar=show_progress_bar)
+        features, track_info = super().transform_dataset(
+            dataset=dataset, show_progress_bar=show_progress_bar)
         # Fit CSP filter
         self.fit(X=features, y=track_info['mi_labels'])
         # Project features into CSP space and obtain log-variance features given
@@ -1045,7 +1046,7 @@ class MIModelCSP(MIModel):
         # Accuracy
         accuracy = np.sum((y_pred == x_info['mi_labels'])) / len(y_pred)
         clf_report = classification_report(x_info['mi_labels'], y_pred,
-                                       output_dict=True)
+                                           output_dict=True)
         assessment = {
             'x': x,
             'x_info': x_info,
@@ -1083,7 +1084,7 @@ class MIModelCSP(MIModel):
         if x_info['mi_labels'] is not None:
             accuracy = np.sum((y_pred == x_info['mi_labels'])) / len(y_pred)
             clf_report = classification_report(x_info['mi_labels'], y_pred,
-                                           output_dict=True)
+                                               output_dict=True)
         decoding = {
             'x': x,
             'x_info': x_info,
@@ -1093,6 +1094,7 @@ class MIModelCSP(MIModel):
         }
         return decoding
 
+
 class MIModelEEGSym(MIModel):
     """Decoding model for MI-based BCI applications based on EEGSym [1], a deep
     convolutional neural network developed for inter-subjects MI classification.
@@ -1133,8 +1135,8 @@ class MIModelEEGSym(MIModel):
 
     def configure(self, cnn_n_cha=8, ch_lateral=3, fine_tuning=False,
                   shuffle_before_fit=True, validation_split=0.4,
-                  init_weights_path=None, gpu_acceleration=True,
-                  augmentation=True):
+                  init_weights_path=None, gpu_acceleration=False,
+                  augmentation=False):
         self.settings = {
             'cnn_n_cha': cnn_n_cha,
             'ch_lateral': ch_lateral,
@@ -1167,6 +1169,7 @@ class MIModelEEGSym(MIModel):
             input_time=2000,
             fs=128,
             n_cha=self.settings['cnn_n_cha'],
+            ch_lateral=self.settings['ch_lateral'],
             filters_per_branch=24,
             scales_time=(125, 250, 500),
             dropout_rate=0.4,
@@ -1195,22 +1198,22 @@ class MIModelEEGSym(MIModel):
         x, x_info = self.get_inst('ext_method').transform_dataset(dataset)
         # Put channels in symmetric order
         x = self.get_inst('clf_method').symmetric_channels(x,
-                                                dataset.channel_set.l_cha)
+                                                           dataset.channel_set.l_cha)
 
         # Classification
         self.get_inst('clf_method').fit(x, x_info['mi_labels'],
-                        fine_tuning=self.settings['fine_tuning'],
-                        shuffle_before_fit=self.settings['shuffle_before_fit'],
-                        validation_split=self.settings['validation_split'],
-                        augmentation=self.settings['augmentation'],
-                        **kwargs)
+                                        fine_tuning=self.settings['fine_tuning'],
+                                        shuffle_before_fit=self.settings['shuffle_before_fit'],
+                                        validation_split=self.settings['validation_split'],
+                                        augmentation=self.settings['augmentation'],
+                                        **kwargs)
         y_prob = self.get_inst('clf_method').predict_proba(x)
         y_pred = y_prob.argmax(axis=-1)
 
         # Accuracy
         accuracy = np.sum((y_pred == x_info['mi_labels'])) / len(y_pred)
         clf_report = classification_report(x_info['mi_labels'], y_pred,
-                                       output_dict=True)
+                                           output_dict=True)
         assessment = {
             'x': x,
             'x_info': x_info,
@@ -1240,7 +1243,7 @@ class MIModelEEGSym(MIModel):
                                                          x_info['onsets'])
         # Put channels in symmetric order
         x = self.get_inst('clf_method').symmetric_channels(x,
-                                                    self.channel_set.l_cha)
+                                                           self.channel_set.l_cha)
         # Classification
         y_prob = self.get_inst('clf_method').predict_proba(x)
         y_pred = y_prob.argmax(axis=-1)
@@ -1251,7 +1254,7 @@ class MIModelEEGSym(MIModel):
         if x_info['mi_labels'] is not None:
             accuracy = np.sum((y_pred == x_info['mi_labels'])) / len(y_pred)
             clf_report = classification_report(x_info['mi_labels'], y_pred,
-                                           output_dict=True)
+                                               output_dict=True)
         decoding = {
             'x': x,
             'x_info': x_info,
