@@ -12,6 +12,7 @@ import warnings
 from abc import ABC, abstractmethod
 import sys, inspect
 import copy, collections
+from threading import Thread
 
 # External imports
 import numpy as np
@@ -1522,3 +1523,18 @@ class Algorithm(ProcessingMethod):
                 alg.methods[method_key]['instance'] = \
                     obj.from_pickleable_obj(method_dict['instance'])
         return alg
+
+class ThreadWithReturnValue(Thread):
+    """This class inherits from thread class and allows getting
+     the target function return"""
+    def __init__(self, group=None, target=None, name=None,
+                 args=(), kwargs={}):
+        Thread.__init__(self, group, target, name, args, kwargs)
+        self._return = None
+    def run(self):
+        if self._target is not None:
+            self._return = self._target(*self._args,
+                                                **self._kwargs)
+    def join(self, *args):
+        Thread.join(self, *args)
+        return self._return
\ No newline at end of file
