@@ -24,199 +24,187 @@ from medusa import components
 eeg_channel_synonyms = {
     'I1': 'O9',
     'I2': 'O10',
+    'O9': 'I1',
+    'O10': 'I2',
     'T3': 'T7',
-    'T4': 'T8'
+    'T4': 'T8',
+    'T7': 'T3',
+    'T8': 'T4',
+    'T5': 'P7',
+    'T6': 'P8'
 }
 
 # EEG standards
-eeg_1020 = {'C3': {'X2D': -0.3249, 'Y2D': 0.0, 'X3D': -0.5878, 'Y3D': 0.0,
-                   'Z3D': 0.809},
-            'C4': {'X2D': 0.3249, 'Y2D': 0.0, 'X3D': 0.5878, 'Y3D': 0.0,
-                   'Z3D': 0.809},
-            'CZ': {'X2D': 0.0, 'Y2D': 0.0, 'X3D': 0.0, 'Y3D': 0.0, 'Z3D': 1.0},
-            'F3': {'X2D': -0.2744, 'Y2D': 0.3467, 'X3D': -0.4591, 'Y3D': 0.58,
-                   'Z3D': 0.673},
-            'F4': {'X2D': 0.2744, 'Y2D': 0.3467, 'X3D': 0.4591, 'Y3D': 0.58,
-                   'Z3D': 0.673},
-            'F7': {'X2D': -0.5879, 'Y2D': 0.427, 'X3D': -0.7695, 'Y3D': 0.559,
-                   'Z3D': 0.309},
-            'F8': {'X2D': 0.5879, 'Y2D': 0.427, 'X3D': 0.7695, 'Y3D': 0.559,
-                   'Z3D': 0.309},
-            'FP1': {'X2D': -0.2245, 'Y2D': 0.691, 'X3D': -0.2939, 'Y3D': 0.9045,
-                    'Z3D': 0.309},
-            'FP2': {'X2D': 0.2245, 'Y2D': 0.691, 'X3D': 0.2939, 'Y3D': 0.9045,
-                    'Z3D': 0.309},
-            'FPZ': {'X2D': 0.0, 'Y2D': 0.7266, 'X3D': 0.0, 'Y3D': 0.9511,
-                    'Z3D': 0.309},
-            'FZ': {'X2D': 0.0, 'Y2D': 0.3249, 'X3D': 0.0, 'Y3D': 0.5878,
-                   'Z3D': 0.809},
-            'LPA': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0,
-                    'Z3D': 0.0},
-            'NAS': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
-            'O1': {'X2D': -0.2245, 'Y2D': -0.691, 'X3D': -0.2939,
-                   'Y3D': -0.9045, 'Z3D': 0.309},
-            'O2': {'X2D': 0.2245, 'Y2D': -0.691, 'X3D': 0.2939, 'Y3D': -0.9045,
-                   'Z3D': 0.309},
-            'OZ': {'X2D': 0.0, 'Y2D': -0.7266, 'X3D': 0.0, 'Y3D': -0.9511,
-                   'Z3D': 0.309},
-            'P3': {'X2D': -0.2744, 'Y2D': -0.3467, 'X3D': -0.4591, 'Y3D': -0.58,
-                   'Z3D': 0.673},
-            'P4': {'X2D': 0.2744, 'Y2D': -0.3467, 'X3D': 0.4591, 'Y3D': -0.58,
-                   'Z3D': 0.673},
-            'P7': {'X2D': -0.5879, 'Y2D': -0.427, 'X3D': -0.7695, 'Y3D': -0.559,
-                   'Z3D': 0.309},
-            'P8': {'X2D': 0.5879, 'Y2D': -0.427, 'X3D': 0.7695, 'Y3D': -0.559,
-                   'Z3D': 0.309},
-            'PZ': {'X2D': 0.0, 'Y2D': -0.3249, 'X3D': 0.0, 'Y3D': -0.5878,
-                   'Z3D': 0.809},
-            'RPA': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
-            'T7': {'X2D': -0.7266, 'Y2D': 0.0, 'X3D': -0.9511, 'Y3D': 0.0,
-                   'Z3D': 0.309},
-            'T8': {'X2D': 0.7266, 'Y2D': 0.0, 'X3D': 0.9511, 'Y3D': 0.0,
-                   'Z3D': 0.309}}
-eeg_1010 = {'AF7': {'X2D': -0.427, 'Y2D': 0.5879, 'X3D': -0.559, 'Y3D': 0.7695,
-                    'Z3D': 0.309},
-            'AF8': {'X2D': 0.427, 'Y2D': 0.5879, 'X3D': 0.559, 'Y3D': 0.7695,
-                    'Z3D': 0.309},
-            'AFZ': {'X2D': 0.0, 'Y2D': 0.5095, 'X3D': 0.0, 'Y3D': 0.809,
-                    'Z3D': 0.5878},
-            'C1': {'X2D': -0.1584, 'Y2D': 0.0, 'X3D': -0.309, 'Y3D': 0.0,
-                   'Z3D': 0.9511},
-            'C2': {'X2D': 0.1584, 'Y2D': 0.0, 'X3D': 0.309, 'Y3D': 0.0,
-                   'Z3D': 0.9511},
-            'C3': {'X2D': -0.3249, 'Y2D': 0.0, 'X3D': -0.5878, 'Y3D': 0.0,
-                   'Z3D': 0.809},
-            'C4': {'X2D': 0.3249, 'Y2D': 0.0, 'X3D': 0.5878, 'Y3D': 0.0,
-                   'Z3D': 0.809},
-            'C5': {'X2D': -0.5095, 'Y2D': 0.0, 'X3D': -0.809, 'Y3D': 0.0,
-                   'Z3D': 0.5878},
-            'C6': {'X2D': 0.5095, 'Y2D': 0.0, 'X3D': 0.809, 'Y3D': 0.0,
-                   'Z3D': 0.5878},
-            'CP1': {'X2D': -0.1527, 'Y2D': -0.1616, 'X3D': -0.2911,
-                    'Y3D': -0.3079, 'Z3D': 0.9058},
-            'CP2': {'X2D': 0.1527, 'Y2D': -0.1616, 'X3D': 0.2911,
-                    'Y3D': -0.3079, 'Z3D': 0.9058},
-            'CP3': {'X2D': -0.3126, 'Y2D': -0.1718, 'X3D': -0.5547,
-                    'Y3D': -0.3048, 'Z3D': 0.7742},
-            'CP4': {'X2D': 0.3126, 'Y2D': -0.1718, 'X3D': 0.5547,
-                    'Y3D': -0.3048, 'Z3D': 0.7742},
-            'CP5': {'X2D': -0.4881, 'Y2D': -0.1912, 'X3D': -0.7658, 'Y3D': -0.3,
-                    'Z3D': 0.5688},
-            'CP6': {'X2D': 0.4881, 'Y2D': -0.1912, 'X3D': 0.7658, 'Y3D': -0.3,
-                    'Z3D': 0.5688},
-            'CPZ': {'X2D': 0.0, 'Y2D': -0.1584, 'X3D': 0.0, 'Y3D': -0.309,
-                    'Z3D': 0.9511},
-            'CZ': {'X2D': 0.0, 'Y2D': 0.0, 'X3D': 0.0, 'Y3D': 0.0, 'Z3D': 1.0},
-            'F1': {'X2D': -0.1349, 'Y2D': 0.3302, 'X3D': -0.2394, 'Y3D': 0.5858,
-                   'Z3D': 0.7743},
-            'F10': {'X2D': 0.809, 'Y2D': 0.5878, 'X3D': 0.809, 'Y3D': 0.5878,
-                    'Z3D': 0.0},
-            'F2': {'X2D': 0.1349, 'Y2D': 0.3302, 'X3D': 0.2394, 'Y3D': 0.5858,
-                   'Z3D': 0.7743},
-            'F3': {'X2D': -0.2744, 'Y2D': 0.3467, 'X3D': -0.4591, 'Y3D': 0.58,
-                   'Z3D': 0.673},
-            'F4': {'X2D': 0.2744, 'Y2D': 0.3467, 'X3D': 0.4591, 'Y3D': 0.58,
-                   'Z3D': 0.673},
-            'F5': {'X2D': -0.4234, 'Y2D': 0.3771, 'X3D': -0.6408, 'Y3D': 0.5708,
-                   'Z3D': 0.5135},
-            'F6': {'X2D': 0.4234, 'Y2D': 0.3771, 'X3D': 0.6408, 'Y3D': 0.5708,
-                   'Z3D': 0.5135},
-            'F7': {'X2D': -0.5879, 'Y2D': 0.427, 'X3D': -0.7695, 'Y3D': 0.559,
-                   'Z3D': 0.309},
-            'F8': {'X2D': 0.5879, 'Y2D': 0.427, 'X3D': 0.7695, 'Y3D': 0.559,
-                   'Z3D': 0.309},
-            'F9': {'X2D': -0.809, 'Y2D': 0.5878, 'X3D': -0.809, 'Y3D': 0.5878,
-                   'Z3D': 0.0},
-            'FC1': {'X2D': -0.1527, 'Y2D': 0.1616, 'X3D': -0.2911,
-                    'Y3D': 0.3079, 'Z3D': 0.9058},
-            'FC2': {'X2D': 0.1527, 'Y2D': 0.1616, 'X3D': 0.2911, 'Y3D': 0.3079,
-                    'Z3D': 0.9058},
-            'FC3': {'X2D': -0.3126, 'Y2D': 0.1718, 'X3D': -0.5547,
-                    'Y3D': 0.3048, 'Z3D': 0.7742},
-            'FC4': {'X2D': 0.3126, 'Y2D': 0.1718, 'X3D': 0.5547, 'Y3D': 0.3048,
-                    'Z3D': 0.7742},
-            'FC5': {'X2D': -0.4881, 'Y2D': 0.1912, 'X3D': -0.7658, 'Y3D': 0.3,
-                    'Z3D': 0.5688},
-            'FC6': {'X2D': 0.4881, 'Y2D': 0.1912, 'X3D': 0.7658, 'Y3D': 0.3,
-                    'Z3D': 0.5688},
-            'FCZ': {'X2D': 0.0, 'Y2D': 0.1584, 'X3D': 0.0, 'Y3D': 0.309,
-                    'Z3D': 0.9511},
-            'FT10': {'X2D': 0.9511, 'Y2D': 0.309, 'X3D': 0.9511, 'Y3D': 0.309,
-                     'Z3D': 0.0},
-            'FT7': {'X2D': -0.691, 'Y2D': 0.2245, 'X3D': -0.9045, 'Y3D': 0.2939,
-                    'Z3D': 0.309},
-            'FT8': {'X2D': 0.691, 'Y2D': 0.2245, 'X3D': 0.9045, 'Y3D': 0.2939,
-                    'Z3D': 0.309},
-            'FT9': {'X2D': -0.9511, 'Y2D': 0.309, 'X3D': -0.9511, 'Y3D': 0.309,
-                    'Z3D': 0.0},
-            'FP1': {'X2D': -0.2245, 'Y2D': 0.691, 'X3D': -0.2939, 'Y3D': 0.9045,
-                    'Z3D': 0.309},
-            'FP2': {'X2D': 0.2245, 'Y2D': 0.691, 'X3D': 0.2939, 'Y3D': 0.9045,
-                    'Z3D': 0.309},
-            'FPZ': {'X2D': 0.0, 'Y2D': 0.7266, 'X3D': 0.0, 'Y3D': 0.9511,
-                    'Z3D': 0.309},
-            'FZ': {'X2D': 0.0, 'Y2D': 0.3249, 'X3D': 0.0, 'Y3D': 0.5878,
-                   'Z3D': 0.809},
-            'I1': {'X2D': -0.309, 'Y2D': -0.9511, 'X3D': -0.309, 'Y3D': -0.9511,
-                   'Z3D': 0.0},
-            'I2': {'X2D': 0.309, 'Y2D': -0.9511, 'X3D': 0.309, 'Y3D': -0.9511,
-                   'Z3D': 0.0},
-            'IZ': {'X2D': 0.0, 'Y2D': -1.0, 'X3D': 0.0, 'Y3D': -1.0,
-                   'Z3D': 0.0},
-            'LPA': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0,
-                    'Z3D': 0.0},
-            'NAS': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
-            'NZ': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
-            'O1': {'X2D': -0.2245, 'Y2D': -0.691, 'X3D': -0.2939,
-                   'Y3D': -0.9045, 'Z3D': 0.309},
-            'O2': {'X2D': 0.2245, 'Y2D': -0.691, 'X3D': 0.2939, 'Y3D': -0.9045,
-                   'Z3D': 0.309},
-            'OZ': {'X2D': 0.0, 'Y2D': -0.7266, 'X3D': 0.0, 'Y3D': -0.9511,
-                   'Z3D': 0.309},
-            'P1': {'X2D': -0.1349, 'Y2D': -0.3302, 'X3D': -0.2394,
-                   'Y3D': -0.5858, 'Z3D': 0.7743},
-            'P10': {'X2D': 0.809, 'Y2D': -0.5878, 'X3D': 0.809, 'Y3D': -0.5878,
-                    'Z3D': 0.0},
-            'P2': {'X2D': 0.1349, 'Y2D': -0.3302, 'X3D': 0.2394, 'Y3D': -0.5858,
-                   'Z3D': 0.7743},
-            'P3': {'X2D': -0.2744, 'Y2D': -0.3467, 'X3D': -0.4591, 'Y3D': -0.58,
-                   'Z3D': 0.673},
-            'P4': {'X2D': 0.2744, 'Y2D': -0.3467, 'X3D': 0.4591, 'Y3D': -0.58,
-                   'Z3D': 0.673},
-            'P5': {'X2D': -0.4234, 'Y2D': -0.3771, 'X3D': -0.6408,
-                   'Y3D': -0.5708, 'Z3D': 0.5135},
-            'P6': {'X2D': 0.4234, 'Y2D': -0.3771, 'X3D': 0.6408, 'Y3D': -0.5708,
-                   'Z3D': 0.5135},
-            'P7': {'X2D': -0.5879, 'Y2D': -0.427, 'X3D': -0.7695, 'Y3D': -0.559,
-                   'Z3D': 0.309},
-            'P8': {'X2D': 0.5879, 'Y2D': -0.427, 'X3D': 0.7695, 'Y3D': -0.559,
-                   'Z3D': 0.309},
-            'P9': {'X2D': -0.809, 'Y2D': -0.5878, 'X3D': -0.809, 'Y3D': -0.5878,
-                   'Z3D': 0.0},
-            'PO10': {'X2D': 0.5878, 'Y2D': -0.809, 'X3D': 0.5878, 'Y3D': -0.809,
-                     'Z3D': 0.0},
-            'PO7': {'X2D': -0.427, 'Y2D': -0.5879, 'X3D': -0.559,
-                    'Y3D': -0.7695, 'Z3D': 0.309},
-            'PO8': {'X2D': 0.427, 'Y2D': -0.5879, 'X3D': 0.559, 'Y3D': -0.7695,
-                    'Z3D': 0.309},
-            'PO9': {'X2D': -0.5878, 'Y2D': -0.809, 'X3D': -0.5878,
-                    'Y3D': -0.809, 'Z3D': 0.0},
-            'POZ': {'X2D': 0.0, 'Y2D': -0.5095, 'X3D': 0.0, 'Y3D': -0.809,
-                    'Z3D': 0.5878},
-            'PZ': {'X2D': 0.0, 'Y2D': -0.3249, 'X3D': 0.0, 'Y3D': -0.5878,
-                   'Z3D': 0.809},
-            'RPA': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
-            'T10': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
-            'T7': {'X2D': -0.7266, 'Y2D': 0.0, 'X3D': -0.9511, 'Y3D': 0.0,
-                   'Z3D': 0.309},
-            'T8': {'X2D': 0.7266, 'Y2D': 0.0, 'X3D': 0.9511, 'Y3D': 0.0,
-                   'Z3D': 0.309},
-            'T9': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0,
-                   'Z3D': 0.0},
-            'TP7': {'X2D': -0.691, 'Y2D': -0.2245, 'X3D': -0.9045,
-                    'Y3D': -0.2939, 'Z3D': 0.309},
-            'TP8': {'X2D': 0.691, 'Y2D': -0.2245, 'X3D': 0.9045, 'Y3D': -0.2939,
-                    'Z3D': 0.309}}
+eeg_1020 = {
+    'C3': {'X2D': -0.3249, 'Y2D': 0.0, 'X3D': -0.5878, 'Y3D': 0.0, 'Z3D': 0.809},
+    'C4': {'X2D': 0.3249, 'Y2D': 0.0, 'X3D': 0.5878, 'Y3D': 0.0, 'Z3D': 0.809},
+    'CZ': {'X2D': 0.0, 'Y2D': 0.0, 'X3D': 0.0, 'Y3D': 0.0, 'Z3D': 1.0},
+    'F3': {'X2D': -0.2744, 'Y2D': 0.3467, 'X3D': -0.4591, 'Y3D': 0.58, 'Z3D': 0.673},
+    'F4': {'X2D': 0.2744, 'Y2D': 0.3467, 'X3D': 0.4591, 'Y3D': 0.58, 'Z3D': 0.673},
+    'F7': {'X2D': -0.5879, 'Y2D': 0.427, 'X3D': -0.7695, 'Y3D': 0.559, 'Z3D': 0.309},
+    'F8': {'X2D': 0.5879, 'Y2D': 0.427, 'X3D': 0.7695, 'Y3D': 0.559, 'Z3D': 0.309},
+    'FP1': {'X2D': -0.2245, 'Y2D': 0.691, 'X3D': -0.2939, 'Y3D': 0.9045, 'Z3D': 0.309},
+    'FP2': {'X2D': 0.2245, 'Y2D': 0.691, 'X3D': 0.2939, 'Y3D': 0.9045, 'Z3D': 0.309},
+    'FPZ': {'X2D': 0.0, 'Y2D': 0.7266, 'X3D': 0.0, 'Y3D': 0.9511, 'Z3D': 0.309},
+    'FZ': {'X2D': 0.0, 'Y2D': 0.3249, 'X3D': 0.0, 'Y3D': 0.5878, 'Z3D': 0.809},
+    'LPA': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0, 'Z3D': 0.0},
+    'NAS': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
+    'O1': {'X2D': -0.2245, 'Y2D': -0.691, 'X3D': -0.2939, 'Y3D': -0.9045, 'Z3D': 0.309},
+    'O2': {'X2D': 0.2245, 'Y2D': -0.691, 'X3D': 0.2939, 'Y3D': -0.9045, 'Z3D': 0.309},
+    'OZ': {'X2D': 0.0, 'Y2D': -0.7266, 'X3D': 0.0, 'Y3D': -0.9511, 'Z3D': 0.309},
+    'P3': {'X2D': -0.2744, 'Y2D': -0.3467, 'X3D': -0.4591, 'Y3D': -0.58, 'Z3D': 0.673},
+    'P4': {'X2D': 0.2744, 'Y2D': -0.3467, 'X3D': 0.4591, 'Y3D': -0.58, 'Z3D': 0.673},
+    'P7': {'X2D': -0.5879, 'Y2D': -0.427, 'X3D': -0.7695, 'Y3D': -0.559, 'Z3D': 0.309},
+    'P8': {'X2D': 0.5879, 'Y2D': -0.427, 'X3D': 0.7695, 'Y3D': -0.559, 'Z3D': 0.309},
+    'PZ': {'X2D': 0.0, 'Y2D': -0.3249, 'X3D': 0.0, 'Y3D': -0.5878, 'Z3D': 0.809},
+    'RPA': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
+    'T7': {'X2D': -0.7266, 'Y2D': 0.0, 'X3D': -0.9511, 'Y3D': 0.0, 'Z3D': 0.309},
+    'T8': {'X2D': 0.7266, 'Y2D': 0.0, 'X3D': 0.9511, 'Y3D': 0.0, 'Z3D': 0.309}}
+
+eeg_1010 = {
+    'AF7': {'X2D': -0.427, 'Y2D': 0.5879, 'X3D': -0.559, 'Y3D': 0.7695,
+            'Z3D': 0.309},
+    'AF8': {'X2D': 0.427, 'Y2D': 0.5879, 'X3D': 0.559, 'Y3D': 0.7695,
+            'Z3D': 0.309},
+    'AFZ': {'X2D': 0.0, 'Y2D': 0.5095, 'X3D': 0.0, 'Y3D': 0.809,
+            'Z3D': 0.5878},
+    'C1': {'X2D': -0.1584, 'Y2D': 0.0, 'X3D': -0.309, 'Y3D': 0.0,
+           'Z3D': 0.9511},
+    'C2': {'X2D': 0.1584, 'Y2D': 0.0, 'X3D': 0.309, 'Y3D': 0.0,
+           'Z3D': 0.9511},
+    'C3': {'X2D': -0.3249, 'Y2D': 0.0, 'X3D': -0.5878, 'Y3D': 0.0,
+           'Z3D': 0.809},
+    'C4': {'X2D': 0.3249, 'Y2D': 0.0, 'X3D': 0.5878, 'Y3D': 0.0,
+           'Z3D': 0.809},
+    'C5': {'X2D': -0.5095, 'Y2D': 0.0, 'X3D': -0.809, 'Y3D': 0.0,
+           'Z3D': 0.5878},
+    'C6': {'X2D': 0.5095, 'Y2D': 0.0, 'X3D': 0.809, 'Y3D': 0.0,
+           'Z3D': 0.5878},
+    'CP1': {'X2D': -0.1527, 'Y2D': -0.1616, 'X3D': -0.2911,
+            'Y3D': -0.3079, 'Z3D': 0.9058},
+    'CP2': {'X2D': 0.1527, 'Y2D': -0.1616, 'X3D': 0.2911,
+            'Y3D': -0.3079, 'Z3D': 0.9058},
+    'CP3': {'X2D': -0.3126, 'Y2D': -0.1718, 'X3D': -0.5547,
+            'Y3D': -0.3048, 'Z3D': 0.7742},
+    'CP4': {'X2D': 0.3126, 'Y2D': -0.1718, 'X3D': 0.5547,
+            'Y3D': -0.3048, 'Z3D': 0.7742},
+    'CP5': {'X2D': -0.4881, 'Y2D': -0.1912, 'X3D': -0.7658, 'Y3D': -0.3,
+            'Z3D': 0.5688},
+    'CP6': {'X2D': 0.4881, 'Y2D': -0.1912, 'X3D': 0.7658, 'Y3D': -0.3,
+            'Z3D': 0.5688},
+    'CPZ': {'X2D': 0.0, 'Y2D': -0.1584, 'X3D': 0.0, 'Y3D': -0.309,
+            'Z3D': 0.9511},
+    'CZ': {'X2D': 0.0, 'Y2D': 0.0, 'X3D': 0.0, 'Y3D': 0.0, 'Z3D': 1.0},
+    'F1': {'X2D': -0.1349, 'Y2D': 0.3302, 'X3D': -0.2394, 'Y3D': 0.5858,
+           'Z3D': 0.7743},
+    'F10': {'X2D': 0.809, 'Y2D': 0.5878, 'X3D': 0.809, 'Y3D': 0.5878,
+            'Z3D': 0.0},
+    'F2': {'X2D': 0.1349, 'Y2D': 0.3302, 'X3D': 0.2394, 'Y3D': 0.5858,
+           'Z3D': 0.7743},
+    'F3': {'X2D': -0.2744, 'Y2D': 0.3467, 'X3D': -0.4591, 'Y3D': 0.58,
+           'Z3D': 0.673},
+    'F4': {'X2D': 0.2744, 'Y2D': 0.3467, 'X3D': 0.4591, 'Y3D': 0.58,
+           'Z3D': 0.673},
+    'F5': {'X2D': -0.4234, 'Y2D': 0.3771, 'X3D': -0.6408, 'Y3D': 0.5708,
+           'Z3D': 0.5135},
+    'F6': {'X2D': 0.4234, 'Y2D': 0.3771, 'X3D': 0.6408, 'Y3D': 0.5708,
+           'Z3D': 0.5135},
+    'F7': {'X2D': -0.5879, 'Y2D': 0.427, 'X3D': -0.7695, 'Y3D': 0.559,
+           'Z3D': 0.309},
+    'F8': {'X2D': 0.5879, 'Y2D': 0.427, 'X3D': 0.7695, 'Y3D': 0.559,
+           'Z3D': 0.309},
+    'F9': {'X2D': -0.809, 'Y2D': 0.5878, 'X3D': -0.809, 'Y3D': 0.5878,
+           'Z3D': 0.0},
+    'FC1': {'X2D': -0.1527, 'Y2D': 0.1616, 'X3D': -0.2911,
+            'Y3D': 0.3079, 'Z3D': 0.9058},
+    'FC2': {'X2D': 0.1527, 'Y2D': 0.1616, 'X3D': 0.2911, 'Y3D': 0.3079,
+            'Z3D': 0.9058},
+    'FC3': {'X2D': -0.3126, 'Y2D': 0.1718, 'X3D': -0.5547,
+            'Y3D': 0.3048, 'Z3D': 0.7742},
+    'FC4': {'X2D': 0.3126, 'Y2D': 0.1718, 'X3D': 0.5547, 'Y3D': 0.3048,
+            'Z3D': 0.7742},
+    'FC5': {'X2D': -0.4881, 'Y2D': 0.1912, 'X3D': -0.7658, 'Y3D': 0.3,
+            'Z3D': 0.5688},
+    'FC6': {'X2D': 0.4881, 'Y2D': 0.1912, 'X3D': 0.7658, 'Y3D': 0.3,
+            'Z3D': 0.5688},
+    'FCZ': {'X2D': 0.0, 'Y2D': 0.1584, 'X3D': 0.0, 'Y3D': 0.309,
+            'Z3D': 0.9511},
+    'FT10': {'X2D': 0.9511, 'Y2D': 0.309, 'X3D': 0.9511, 'Y3D': 0.309,
+             'Z3D': 0.0},
+    'FT7': {'X2D': -0.691, 'Y2D': 0.2245, 'X3D': -0.9045, 'Y3D': 0.2939,
+            'Z3D': 0.309},
+    'FT8': {'X2D': 0.691, 'Y2D': 0.2245, 'X3D': 0.9045, 'Y3D': 0.2939,
+            'Z3D': 0.309},
+    'FT9': {'X2D': -0.9511, 'Y2D': 0.309, 'X3D': -0.9511, 'Y3D': 0.309,
+            'Z3D': 0.0},
+    'FP1': {'X2D': -0.2245, 'Y2D': 0.691, 'X3D': -0.2939, 'Y3D': 0.9045,
+            'Z3D': 0.309},
+    'FP2': {'X2D': 0.2245, 'Y2D': 0.691, 'X3D': 0.2939, 'Y3D': 0.9045,
+            'Z3D': 0.309},
+    'FPZ': {'X2D': 0.0, 'Y2D': 0.7266, 'X3D': 0.0, 'Y3D': 0.9511,
+            'Z3D': 0.309},
+    'FZ': {'X2D': 0.0, 'Y2D': 0.3249, 'X3D': 0.0, 'Y3D': 0.5878,
+           'Z3D': 0.809},
+    'I1': {'X2D': -0.309, 'Y2D': -0.9511, 'X3D': -0.309, 'Y3D': -0.9511,
+           'Z3D': 0.0},
+    'I2': {'X2D': 0.309, 'Y2D': -0.9511, 'X3D': 0.309, 'Y3D': -0.9511,
+           'Z3D': 0.0},
+    'IZ': {'X2D': 0.0, 'Y2D': -1.0, 'X3D': 0.0, 'Y3D': -1.0,
+           'Z3D': 0.0},
+    'LPA': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0,
+            'Z3D': 0.0},
+    'NAS': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
+    'NZ': {'X2D': 0.0, 'Y2D': 1.0, 'X3D': 0.0, 'Y3D': 1.0, 'Z3D': 0.0},
+    'O1': {'X2D': -0.2245, 'Y2D': -0.691, 'X3D': -0.2939,
+           'Y3D': -0.9045, 'Z3D': 0.309},
+    'O2': {'X2D': 0.2245, 'Y2D': -0.691, 'X3D': 0.2939, 'Y3D': -0.9045,
+           'Z3D': 0.309},
+    'OZ': {'X2D': 0.0, 'Y2D': -0.7266, 'X3D': 0.0, 'Y3D': -0.9511,
+           'Z3D': 0.309},
+    'P1': {'X2D': -0.1349, 'Y2D': -0.3302, 'X3D': -0.2394,
+           'Y3D': -0.5858, 'Z3D': 0.7743},
+    'P10': {'X2D': 0.809, 'Y2D': -0.5878, 'X3D': 0.809, 'Y3D': -0.5878,
+            'Z3D': 0.0},
+    'P2': {'X2D': 0.1349, 'Y2D': -0.3302, 'X3D': 0.2394, 'Y3D': -0.5858,
+           'Z3D': 0.7743},
+    'P3': {'X2D': -0.2744, 'Y2D': -0.3467, 'X3D': -0.4591, 'Y3D': -0.58,
+           'Z3D': 0.673},
+    'P4': {'X2D': 0.2744, 'Y2D': -0.3467, 'X3D': 0.4591, 'Y3D': -0.58,
+           'Z3D': 0.673},
+    'P5': {'X2D': -0.4234, 'Y2D': -0.3771, 'X3D': -0.6408,
+           'Y3D': -0.5708, 'Z3D': 0.5135},
+    'P6': {'X2D': 0.4234, 'Y2D': -0.3771, 'X3D': 0.6408, 'Y3D': -0.5708,
+           'Z3D': 0.5135},
+    'P7': {'X2D': -0.5879, 'Y2D': -0.427, 'X3D': -0.7695, 'Y3D': -0.559,
+           'Z3D': 0.309},
+    'P8': {'X2D': 0.5879, 'Y2D': -0.427, 'X3D': 0.7695, 'Y3D': -0.559,
+           'Z3D': 0.309},
+    'P9': {'X2D': -0.809, 'Y2D': -0.5878, 'X3D': -0.809, 'Y3D': -0.5878,
+           'Z3D': 0.0},
+    'PO10': {'X2D': 0.5878, 'Y2D': -0.809, 'X3D': 0.5878, 'Y3D': -0.809,
+             'Z3D': 0.0},
+    'PO7': {'X2D': -0.427, 'Y2D': -0.5879, 'X3D': -0.559,
+            'Y3D': -0.7695, 'Z3D': 0.309},
+    'PO8': {'X2D': 0.427, 'Y2D': -0.5879, 'X3D': 0.559, 'Y3D': -0.7695,
+            'Z3D': 0.309},
+    'PO9': {'X2D': -0.5878, 'Y2D': -0.809, 'X3D': -0.5878,
+            'Y3D': -0.809, 'Z3D': 0.0},
+    'POZ': {'X2D': 0.0, 'Y2D': -0.5095, 'X3D': 0.0, 'Y3D': -0.809,
+            'Z3D': 0.5878},
+    'PZ': {'X2D': 0.0, 'Y2D': -0.3249, 'X3D': 0.0, 'Y3D': -0.5878,
+           'Z3D': 0.809},
+    'RPA': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
+    'T10': {'X2D': 1.0, 'Y2D': 0.0, 'X3D': 1.0, 'Y3D': 0.0, 'Z3D': 0.0},
+    'T7': {'X2D': -0.7266, 'Y2D': 0.0, 'X3D': -0.9511, 'Y3D': 0.0,
+           'Z3D': 0.309},
+    'T8': {'X2D': 0.7266, 'Y2D': 0.0, 'X3D': 0.9511, 'Y3D': 0.0,
+           'Z3D': 0.309},
+    'T9': {'X2D': -1.0, 'Y2D': 0.0, 'X3D': -1.0, 'Y3D': 0.0,
+           'Z3D': 0.0},
+    'TP7': {'X2D': -0.691, 'Y2D': -0.2245, 'X3D': -0.9045,
+            'Y3D': -0.2939, 'Z3D': 0.309},
+    'TP8': {'X2D': 0.691, 'Y2D': -0.2245, 'X3D': 0.9045, 'Y3D': -0.2939,
+            'Z3D': 0.309}}
 eeg_1005 = {
     'AF1': {'X2D': -0.1025, 'Y2D': 0.5139, 'X3D': -0.1608, 'Y3D': 0.8064,
             'Z3D': 0.5692},
@@ -1140,7 +1128,7 @@ class EEGChannelSet(components.SerializableComponent):
             standard_data = eeg_1005.copy()
         # Get list of labels to get
         l_cha = standard_data.keys() if l_cha is None \
-            else [l.upper() for l in l_cha]
+            else [l.upper().strip() for l in l_cha]
         # Reference
         if l_reference is not None:
             reference = self.get_standard_channel_data_from_label(
